aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorUlf Lamping <ulf.lamping@web.de>2004-10-20 18:50:58 +0000
committerUlf Lamping <ulf.lamping@web.de>2004-10-20 18:50:58 +0000
commit0f80fa5c7d747a026d4fd30220a98d087cef53b1 (patch)
tree32d5522fd1cd1a87e2803b0df458fe6fb77d99ba
parent39de90e5da056fd473dfd0b47f4e4d06ea4aa8d3 (diff)
renamed capinfo to capinfos, as the former name capinfo was already used in a program called tcprelay, so that might confuse packaging managers and users. Hopefully I got all the places need to be changed.
svn path=/trunk/; revision=12358
-rw-r--r--Makefile.am26
-rw-r--r--Makefile.nmake12
-rw-r--r--capinfos.c (renamed from capinfo.c)10
-rw-r--r--configure.in22
-rw-r--r--doc/Makefile.am14
-rw-r--r--doc/Makefile.nmake16
-rw-r--r--doc/capinfos.pod (renamed from doc/capinfo.pod)30
-rw-r--r--docbook/eug_src/EUG_app_tools.xml16
-rw-r--r--docbook/eug_src/EUG_chapter_build_install.xml2
-rw-r--r--image/Makefile.nmake6
-rwxr-xr-ximage/capinfos.rc.in (renamed from image/capinfo.rc.in)8
-rw-r--r--packaging/nsis/Makefile.nmake4
-rw-r--r--packaging/nsis/ethereal.nsi8
13 files changed, 87 insertions, 87 deletions
diff --git a/Makefile.am b/Makefile.am
index 1f8899ae84..219a5015a8 100644
--- a/Makefile.am
+++ b/Makefile.am
@@ -60,13 +60,13 @@ ACLOCAL_AMFLAGS = `./aclocal-flags`
# automake will arrange that the Makefile define it as the union of all
# the "man{section}_MANS" variables.
#
-bin_PROGRAMS = @ethereal_bin@ @capinfo_bin@ @editcap_bin@ @mergecap_bin@ @tethereal_bin@ @dftest_bin@ @randpkt_bin@ @text2pcap_bin@
+bin_PROGRAMS = @ethereal_bin@ @capinfos_bin@ @editcap_bin@ @mergecap_bin@ @tethereal_bin@ @dftest_bin@ @randpkt_bin@ @text2pcap_bin@
bin_SCRIPTS = @idl2eth_bin@
-man1_MANS = @ethereal_man@ @capinfo_man@ @editcap_man@ @mergecap_man@ @tethereal_man@ @text2pcap_man@ @idl2eth_man@
+man1_MANS = @ethereal_man@ @capinfos_man@ @editcap_man@ @mergecap_man@ @tethereal_man@ @text2pcap_man@ @idl2eth_man@
man4_MANS = @etherealfilter_man@
man_MANS =
-EXTRA_PROGRAMS = ethereal tethereal capinfo editcap mergecap dftest \
+EXTRA_PROGRAMS = ethereal tethereal capinfos editcap mergecap dftest \
randpkt text2pcap
EXTRA_SCRIPTS = idl2eth
@@ -75,7 +75,7 @@ EXTRA_SCRIPTS = idl2eth
# contains the "AUTHORS-SHORT" and "manuf" files and a "diameter" directory.
#
pkgdata_DATA = AUTHORS-SHORT manuf ethereal.html tethereal.html \
- ethereal-filter.html capinfo.html editcap.html \
+ ethereal-filter.html capinfos.html editcap.html \
idl2eth.html mergecap.html text2pcap.html
#
@@ -277,11 +277,11 @@ text2pcap_LDADD = $(text2pcap_optional_objects) \
mergecap_DEPENDENCIES = wiretap/libwiretap.la
# This is the automake dependency variable for the executable
-capinfo_DEPENDENCIES = wiretap/libwiretap.la
+capinfos_DEPENDENCIES = wiretap/libwiretap.la
editcap_DEPENDENCIES = wiretap/libwiretap.la
# This automake variable adds to the link-line for the executable
-capinfo_LDADD = wiretap/libwiretap.la @GLIB_LIBS@
+capinfos_LDADD = wiretap/libwiretap.la @GLIB_LIBS@
editcap_LDADD = wiretap/libwiretap.la @GLIB_LIBS@
mergecap_LDADD = wiretap/libwiretap.la @GLIB_LIBS@
@@ -411,7 +411,7 @@ EXTRA_DIST = \
aclocal-fallback/gtk.m4 \
aclocal-flags \
autogen.sh \
- capinfo.c \
+ capinfos.c \
capture-wpcap.c \
capture-wpcap.h \
cleanbld.bat \
@@ -440,7 +440,7 @@ EXTRA_DIST = \
doc/README.tapping \
doc/README.tvbuff \
doc/README.xml-output \
- doc/capinfo.pod \
+ doc/capinfos.pod \
doc/dfilter2pod.pl \
doc/editcap.pod \
doc/ethereal-filter.pod.template \
@@ -462,7 +462,7 @@ EXTRA_DIST = \
image/Ethereal.icns \
image/Makefile.nmake \
image/README.image \
- image/capinfo.rc.in \
+ image/capinfos.rc.in \
image/clist_ascend.xpm \
image/clist_descend.xpm \
image/dn_arrow.xpm \
@@ -577,9 +577,9 @@ ethereal-filter.4: tethereal doc/ethereal-filter.pod.template
(cd doc ; \
$(MAKE) ../ethereal-filter.4 )
-capinfo.1: doc/capinfo.pod
+capinfos.1: doc/capinfos.pod
(cd doc ; \
- $(MAKE) ../capinfo.1 )
+ $(MAKE) ../capinfos.1 )
editcap.1: doc/editcap.pod
(cd doc ; \
@@ -609,9 +609,9 @@ ethereal-filter.html: tethereal doc/ethereal-filter.pod.template
(cd doc ; \
$(MAKE) ../ethereal-filter.html )
-capinfo.html: doc/capinfo.pod
+capinfos.html: doc/capinfos.pod
(cd doc ; \
- $(MAKE) ../capinfo.html )
+ $(MAKE) ../capinfos.html )
editcap.html: doc/editcap.pod
(cd doc ; \
diff --git a/Makefile.nmake b/Makefile.nmake
index 679d361cfd..e741cb3efd 100644
--- a/Makefile.nmake
+++ b/Makefile.nmake
@@ -78,7 +78,7 @@ tethereal_LIBS= wiretap\wiretap-$(WTAP_VERSION).lib \
$(ZLIB_LIBS)
!ENDIF
-capinfo_LIBS= wiretap\wiretap-$(WTAP_VERSION).lib \
+capinfos_LIBS= wiretap\wiretap-$(WTAP_VERSION).lib \
wsock32.lib user32.lib \
$(GLIB_LIBS)
@@ -111,10 +111,10 @@ randpkt_LIBS= wiretap\wiretap-$(WTAP_VERSION).lib \
$(NET_SNMP_DIR)\win32\lib\release\netsnmp.lib
EXECUTABLES=ethereal.exe ethereal-gtk2.exe tethereal.exe \
- capinfo.exe editcap.exe mergecap.exe text2pcap.exe
+ capinfos.exe editcap.exe mergecap.exe text2pcap.exe
RESOURCES=image\ethereal.res image\libethereal.res image\tethereal.res \
- image\capinfo.res image\editcap.res image\mergecap.res \
+ image\capinfos.res image\editcap.res image\mergecap.res \
image\text2pcap.res image\wiretap.res
all: config.h tools image wiretap epan $(EXECUTABLES) $(RESOURCES) doc
@@ -168,10 +168,10 @@ tethereal.exe : config.h svnversion.h $(tethereal_OBJECTS) epan image\tethereal.
/OUT:tethereal.exe $(conflags) $(conlibsdll) $(LDFLAGS) /SUBSYSTEM:console $(tethereal_LIBS) $(tethereal_OBJECTS) image\tethereal.res
<<
-capinfo.exe : config.h capinfo.obj getopt.obj wiretap\wiretap-$(WTAP_VERSION).lib image\capinfo.res
+capinfos.exe : config.h capinfos.obj getopt.obj wiretap\wiretap-$(WTAP_VERSION).lib image\capinfos.res
@echo Linking $@
$(LINK) @<<
- /OUT:capinfo.exe $(conflags) $(conlibsdll) $(LDFLAGS) /SUBSYSTEM:console capinfo.obj getopt.obj $(capinfo_LIBS) image\capinfo.res
+ /OUT:capinfos.exe $(conflags) $(conlibsdll) $(LDFLAGS) /SUBSYSTEM:console capinfos.obj getopt.obj $(capinfos_LIBS) image\capinfos.res
<<
editcap.exe : config.h editcap.obj getopt.obj wiretap\wiretap-$(WTAP_VERSION).lib image\editcap.res
@@ -268,7 +268,7 @@ gtk2_distclean:
clean: gtk2_distclean
rm -f $(ethereal_OBJECTS) $(tethereal_OBJECTS) $(EXTRA_OBJECTS) \
$(EXECUTABLES) $(PDB_FILE) \
- capinfo.obj editcap.obj mergecap.obj text2pcap.obj getopt.obj\
+ capinfos.obj editcap.obj mergecap.obj text2pcap.obj getopt.obj\
text2pcap-scanner.obj text2pcap-scanner.c rdps.obj \
rdps.pdb rdps.exe rdps.ilk config.h ps.c AUTHORS-SHORT \
AUTHORS-SHORT-FORMAT \
diff --git a/configure.in b/configure.in
index 2962626627..234792caff 100644
--- a/configure.in
+++ b/configure.in
@@ -510,20 +510,20 @@ AC_SUBST(editcap_bin)
AC_SUBST(editcap_man)
-# Enable/disable capinfo
+# Enable/disable capinfos
-AC_ARG_ENABLE(capinfo,
-[ --enable-capinfo build capinfo. [default=yes]],enable_capinfo=$enableval,enable_capinfo=yes)
+AC_ARG_ENABLE(capinfos,
+[ --enable-capinfos build capinfos. [default=yes]],enable_capinfos=$enableval,enable_capinfos=yes)
-if test "x$enable_capinfo" = "xyes" ; then
- capinfo_bin="capinfo\$(EXEEXT)"
- capinfo_man="capinfo.1"
+if test "x$enable_capinfos" = "xyes" ; then
+ capinfos_bin="capinfos\$(EXEEXT)"
+ capinfos_man="capinfos.1"
else
- capinfo_bin=""
- capinfo_man=""
+ capinfos_bin=""
+ capinfos_man=""
fi
-AC_SUBST(capinfo_bin)
-AC_SUBST(capinfo_man)
+AC_SUBST(capinfos_bin)
+AC_SUBST(capinfos_man)
# Enable/disable mergecap
@@ -1302,7 +1302,7 @@ echo ""
echo "The Ethereal package has been configured with the following options."
echo " Build ethereal : $enable_ethereal"
echo " Build tethereal : $enable_tethereal"
-echo " Build capinfo : $enable_capinfo"
+echo " Build capinfos : $enable_capinfos"
echo " Build editcap : $enable_editcap"
echo " Build mergecap : $enable_mergecap"
echo " Build text2pcap : $enable_text2pcap"
diff --git a/doc/Makefile.am b/doc/Makefile.am
index 8857c94e4c..9b0f75f4fb 100644
--- a/doc/Makefile.am
+++ b/doc/Makefile.am
@@ -67,17 +67,17 @@ ethereal-tmp.pod: $(srcdir)/ethereal.pod $(top_srcdir)/AUTHORS-SHORT-FORMAT
ethereal-filter.pod: ethereal-filter.pod.template ../tethereal
../tethereal -G fields | $(PERL) $(srcdir)/dfilter2pod.pl $(srcdir)/ethereal-filter.pod.template > ethereal-filter.pod
-../capinfo.1: capinfo.pod ../config.h
+../capinfos.1: capinfos.pod ../config.h
$(POD2MAN) \
--center="The Ethereal Network Analyzer" \
--release=$(VERSION) \
- $(srcdir)/capinfo.pod > ../capinfo.1
+ $(srcdir)/capinfos.pod > ../capinfos.1
-../capinfo.html: capinfo.pod ../config.h
+../capinfos.html: capinfos.pod ../config.h
$(POD2HTML) \
- --title="capinfo - The Ethereal Network Analyzer $(VERSION)" \
+ --title="capinfos - The Ethereal Network Analyzer $(VERSION)" \
--noindex \
- capinfo.pod > ../capinfo.html
+ capinfos.pod > ../capinfos.html
../editcap.1: editcap.pod ../config.h
$(POD2MAN) \
@@ -134,8 +134,8 @@ CLEANFILES = \
../ethereal-filter.html \
../ethereal.1 \
../ethereal.html \
- ../capinfo.1 \
- ../capinfo.html \
+ ../capinfos.1 \
+ ../capinfos.html \
../editcap.1 \
../editcap.html \
../mergecap.1 \
diff --git a/doc/Makefile.nmake b/doc/Makefile.nmake
index 5216a23b73..63f8f70455 100644
--- a/doc/Makefile.nmake
+++ b/doc/Makefile.nmake
@@ -26,10 +26,10 @@
include ../config.nmake
-doc: ethereal.html tethereal.html ethereal-filter.html capinfo.html \
+doc: ethereal.html tethereal.html ethereal-filter.html capinfos.html \
editcap.html idl2eth.html mergecap.html text2pcap.html
-man: ethereal.1 tethereal.1 ethereal-filter.4 capinfo.1 editcap.1 \
+man: ethereal.1 tethereal.1 ethereal-filter.4 capinfos.1 editcap.1 \
idl2eth.1 mergecap.1 text2pcap.1
ethereal-tmp.pod: ethereal.pod ../AUTHORS-SHORT-FORMAT
@@ -91,17 +91,17 @@ ethereal-filter.pod: ethereal-filter.pod.template ../tethereal.exe
rm -f libethereal.dll wiretap-$(WTAP_VERSION).dll
cd doc
-capinfo.1: capinfo.pod ../config.h
+capinfos.1: capinfos.pod ../config.h
$(POD2MAN) \
--center="The Ethereal Network Analyzer" \
--release=$(VERSION) \
- capinfo.pod > capinfo.1
+ capinfos.pod > capinfos.1
-capinfo.html: capinfo.pod ../config.h
+capinfos.html: capinfos.pod ../config.h
$(POD2HTML) \
- --title="capinfo - The Ethereal Network Analyzer $(VERSION)" \
+ --title="capinfos - The Ethereal Network Analyzer $(VERSION)" \
--noindex \
- capinfo.pod > capinfo.html
+ capinfos.pod > capinfos.html
editcap.1: editcap.pod ../config.h
@@ -156,7 +156,7 @@ clean:
rm -f ethereal.html ethereal.1 ethereal-tmp.pod
rm -f tethereal.html tethereal.1
rm -f ethereal-filter.html ethereal-filter.4 ethereal-filter.pod
- rm -f capinfo.html capinfo.1
+ rm -f capinfos.html capinfos.1
rm -f editcap.html editcap.1
rm -f idl2eth.html idl2eth.1
rm -f mergecap.html mergecap.1
diff --git a/doc/capinfo.pod b/doc/capinfos.pod
index 2ca0f55ec5..ce9a40d40a 100644
--- a/doc/capinfo.pod
+++ b/doc/capinfos.pod
@@ -1,11 +1,11 @@
=head1 NAME
-capinfo - Prints information about binary capture files
+capinfos - Prints information about binary capture files
=head1 SYNOPSYS
-B<capinfo>
+B<capinfos>
S<[ B<-t> ]>
S<[ B<-c> ]>
S<[ B<-s> ]>
@@ -21,11 +21,11 @@ I<capfile>
=head1 DESCRIPTION
-B<Capinfo> is a program that reads a saved capture file and returns any
-or all of several statistics about that file. B<Capinfo> is able to detect
+B<Capinfos> is a program that reads a saved capture file and returns any
+or all of several statistics about that file. B<Capinfos> is able to detect
and read any capture supported by the B<Ethereal> package.
-B<Capinfo> can read the following file formats:
+B<Capinfos> can read the following file formats:
=over 4
@@ -109,14 +109,14 @@ Linux Bluez Bluetooth stack B<hcidump -w> traces
=back
-There is no need to tell B<Capinfo> what type of
+There is no need to tell B<Capinfos> what type of
file you are reading; it will determine the file type by itself.
-B<Capinfo> is also capable of reading any of these file formats if they
-are compressed using gzip. B<Capinfo> recognizes this directly from the
+B<Capinfos> is also capable of reading any of these file formats if they
+are compressed using gzip. B<Capinfos> recognizes this directly from the
file; the '.gz' extension is not required for this purpose.
The user specifies which statistics to report by specifying flags
-corresponding to the statistic. If no flags are specified, B<Capinfo> will
+corresponding to the statistic. If no flags are specified, B<Capinfos> will
report all statistics available.
=head1 OPTIONS
@@ -144,7 +144,7 @@ in their original form, not as they appear in this file.
For example, if a packet was originally 1514 bytes and only
256 of those bytes were saved to the capture file (if packets
were captured with a snaplen or other slicing option),
-B<Capinfo> will consider the packet to have been 1514 bytes.
+B<Capinfos> will consider the packet to have been 1514 bytes.
=item -u
@@ -154,19 +154,19 @@ latest packet seen.
=item -a
-Displays the start time of the capture. B<Capinfo> considers
+Displays the start time of the capture. B<Capinfos> considers
the earliest timestamp seen to be the start time, so the
first packet in the capture is not necessarily the earliest -
if packets exist "out-of-order", time-wise, in the capture,
-B<Capinfo> detects this.
+B<Capinfos> detects this.
=item -e
-Displays the end time of the capture. B<Capinfo> considers
+Displays the end time of the capture. B<Capinfos> considers
the latest timestamp seen to be the end time, so the
last packet in the capture is not necessarily the latest -
if packets exist "out-of-order", time-wise, in the capture,
-B<Capinfo> detects this.
+B<Capinfos> detects this.
=item -y
@@ -192,7 +192,7 @@ I<tcpdump(8)>, I<pcap(3)>, I<ethereal(1)>, I<mergecap(1)>, I<editcap(1)>, I<teth
=head1 NOTES
-B<Capinfo> is part of the B<Ethereal> distribution. The latest version
+B<Capinfos> is part of the B<Ethereal> distribution. The latest version
of B<Ethereal> can be found at B<http://www.ethereal.com>.
=head1 AUTHORS
diff --git a/docbook/eug_src/EUG_app_tools.xml b/docbook/eug_src/EUG_app_tools.xml
index c23c811ef4..ecf24c082f 100644
--- a/docbook/eug_src/EUG_app_tools.xml
+++ b/docbook/eug_src/EUG_app_tools.xml
@@ -60,20 +60,20 @@ tcpdump -i &lt;interface> -s 1500 -w &lt;some-file>
</para>
</section>
- <section id="AppToolscapinfo">
- <title>capinfo: Print information about capture files</title>
+ <section id="AppToolscapinfos">
+ <title>capinfos: Print information about capture files</title>
<para>
Included with Ethereal is a small utility called
- <command>capinfo</command>, which is a command-line utility to
+ <command>capinfos</command>, which is a command-line utility to
print information about binary capture files.
</para>
<para>
- <example id="AppToolscapinfoEx">
- <title>Help information available from capinfo</title>
+ <example id="AppToolscapinfosEx">
+ <title>Help information available from capinfos</title>
<programlisting>
-$ capinfo -h
-Usage: capinfo [-t] [-c] [-s] [-d] [-u] [-a] [-e] [-y]
- [-i] [-z] [-h] &lt;capfile&gt;
+$ capinfos -h
+Usage: capinfos [-t] [-c] [-s] [-d] [-u] [-a] [-e] [-y]
+ [-i] [-z] [-h] &lt;capfile&gt;
where -t display the capture type of &lt;capfile&gt;
-c count the number of packets
-s display the size of the file
diff --git a/docbook/eug_src/EUG_chapter_build_install.xml b/docbook/eug_src/EUG_chapter_build_install.xml
index d18f2ca1fc..1cedce358b 100644
--- a/docbook/eug_src/EUG_chapter_build_install.xml
+++ b/docbook/eug_src/EUG_chapter_build_install.xml
@@ -515,7 +515,7 @@ apt-get install ethereal
saved capture files into a single output file.
</para></listitem>
<listitem><para>
- <command>Capinfo</command> - Capinfo is a program that provides
+ <command>Capinfos</command> - Capinfos is a program that provides
information on capture files.
</para></listitem>
</itemizedlist>
diff --git a/image/Makefile.nmake b/image/Makefile.nmake
index db4b2b49aa..9c76df1a0d 100644
--- a/image/Makefile.nmake
+++ b/image/Makefile.nmake
@@ -4,7 +4,7 @@
include ..\config.nmake
-ALL_RC=ethereal.rc libethereal.rc tethereal.rc capinfo.rc editcap.rc text2pcap.rc mergecap.rc wiretap.rc
+ALL_RC=ethereal.rc libethereal.rc tethereal.rc capinfos.rc editcap.rc text2pcap.rc mergecap.rc wiretap.rc
all : $(ALL_RC)
ethereal.rc : ethereal.rc.in ..\config.nmake
@@ -22,10 +22,10 @@ tethereal.rc : tethereal.rc.in ..\config.nmake
-e s/@RC_VERSION@/$(RC_VERSION)/ \
< tethereal.rc.in > $@
-capinfo.rc : capinfo.rc.in ..\config.nmake
+capinfos.rc : capinfos.rc.in ..\config.nmake
sed -e s/@VERSION@/$(VERSION)/ \
-e s/@RC_VERSION@/$(RC_VERSION)/ \
- < capinfo.rc.in > $@
+ < capinfos.rc.in > $@
editcap.rc : editcap.rc.in ..\config.nmake
sed -e s/@VERSION@/$(VERSION)/ \
diff --git a/image/capinfo.rc.in b/image/capinfos.rc.in
index 36cc6fa2e2..e82463d6c6 100755
--- a/image/capinfo.rc.in
+++ b/image/capinfos.rc.in
@@ -20,12 +20,12 @@ BEGIN
BLOCK "040904b0"
BEGIN
VALUE "CompanyName", "The Ethereal developer community\0"
- VALUE "FileDescription", "Capinfo\0"
+ VALUE "FileDescription", "Capinfos\0"
VALUE "FileVersion", "@VERSION@\0"
- VALUE "InternalName", "Capinfo @VERSION@\0"
+ VALUE "InternalName", "Capinfos @VERSION@\0"
VALUE "LegalCopyright", "Copyright © 2000 Gerald Combs <gerald@ethereal.com>, Gilbert Ramirez <gram@alumni.rice.edu> and others\0"
- VALUE "OriginalFilename", "Capinfo.exe\0"
- VALUE "ProductName", "Capinfo\0"
+ VALUE "OriginalFilename", "Capinfos.exe\0"
+ VALUE "ProductName", "Capinfos\0"
VALUE "ProductVersion", "@VERSION@\0"
END
END
diff --git a/packaging/nsis/Makefile.nmake b/packaging/nsis/Makefile.nmake
index ef3e3fa0be..1642254baf 100644
--- a/packaging/nsis/Makefile.nmake
+++ b/packaging/nsis/Makefile.nmake
@@ -42,7 +42,7 @@ EXE=../../tethereal.exe ../../editcap.exe \
!IFDEF GTK2_DIR
../../ethereal-gtk2.exe \
!ENDIF
- ../../text2pcap.exe ../../mergecap.exe ../../capinfo.exe
+ ../../text2pcap.exe ../../mergecap.exe ../../capinfos.exe
DLL=../../wiretap/wiretap-$(WTAP_VERSION).dll
DOC=../../doc/ethereal.html \
../../doc/tethereal.html \
@@ -50,7 +50,7 @@ DOC=../../doc/ethereal.html \
../../doc/editcap.html \
../../doc/text2pcap.html \
../../doc/mergecap.html \
- ../../doc/capinfo.html \
+ ../../doc/capinfos.html \
../../FAQ \
../../README \
../../README.win32
diff --git a/packaging/nsis/ethereal.nsi b/packaging/nsis/ethereal.nsi
index 660c0f1c44..c120ac7cef 100644
--- a/packaging/nsis/ethereal.nsi
+++ b/packaging/nsis/ethereal.nsi
@@ -394,14 +394,14 @@ File "..\..\mergecap.exe"
File "..\..\doc\mergecap.html"
SectionEnd
-Section "Capinfo" SecCapinfo
+Section "Capinfos" SecCapinfos
;-------------------------------------------
!ifdef GTK1_DIR & GTK2_DIR
SectionIn 1 2
!endif
SetOutPath $INSTDIR
-File "..\..\capinfo.exe"
-File "..\..\doc\capinfo.html"
+File "..\..\capinfos.exe"
+File "..\..\doc\capinfos.html"
SectionEnd
@@ -676,7 +676,7 @@ SectionEnd
!insertmacro MUI_DESCRIPTION_TEXT ${SecEditCap} "Editcap is a program that reads a capture file and writes some or all of the packets into another capture file."
!insertmacro MUI_DESCRIPTION_TEXT ${SecText2Pcap} "Text2pcap is a program that reads in an ASCII hex dump and writes the data into a libpcap-style capture file."
!insertmacro MUI_DESCRIPTION_TEXT ${SecMergecap} "Mergecap is a program that combines multiple saved capture files into a single output file."
- !insertmacro MUI_DESCRIPTION_TEXT ${SecCapinfo} "Capinfo is a program that provides information on capture files."
+ !insertmacro MUI_DESCRIPTION_TEXT ${SecCapinfos} "Capinfos is a program that provides information on capture files."
!insertmacro MUI_DESCRIPTION_TEXT ${SecPlugins} "Plugins with some extended dissections."
!insertmacro MUI_DESCRIPTION_TEXT ${SecMIBs} "SNMP MIBs for better SNMP dissection."
!insertmacro MUI_DESCRIPTION_TEXT ${SecShortcuts} "Start menu shortcuts."
diff --git a/capinfo.c b/capinfos.c
index c39cccd621..5fb5eb1d5b 100644
--- a/capinfo.c
+++ b/capinfos.c
@@ -1,4 +1,4 @@
-/* capinfo.c
+/* capinfos.c
* Reports capture file information including # of packets, duration, others
*
* Copyright 2004 Ian Schorr
@@ -195,15 +195,15 @@ static void usage(gboolean is_error)
if (!is_error) {
output = stdout;
/* XXX - add capinfo header info here */
}
else {
output = stderr;
}
- fprintf(output, "Usage: capinfo [-t] [-c] [-s] [-d] [-u] [-a] [-e] [-y]\n");
- fprintf(output, " [-i] [-z] [-h] <capfile>\n");
+ fprintf(output, "Usage: capinfos [-t] [-c] [-s] [-d] [-u] [-a] [-e] [-y]\n");
+ fprintf(output, " [-i] [-z] [-h] <capfile>\n");
fprintf(output, " where\t-t display the capture type of <capfile>\n");
fprintf(output, " \t-c count the number of packets\n");
fprintf(output, " \t-s display the size of the file \n");
@@ -311,7 +311,7 @@ int main(int argc, char *argv[])
wth = wtap_open_offline(argv[optind], &err, &err_info, FALSE);
if (!wth) {
- fprintf(stderr, "editcap: Can't open %s: %s\n", argv[optind],
+ fprintf(stderr, "capinfos: Can't open %s: %s\n", argv[optind],
wtap_strerror(err));
switch (err) {
@@ -195,15 +195,15 @@ static void usage(gboolean is_error)
if (!is_error) {
output = stdout;
- /* XXX - add capinfo header info here */
+ /* XXX - add capinfos header info here */
}
else {